@@ -1,21 +1,21 @@
 #!/bin/bash
 # PHP-5.2	(http://www.php.net)
-#	BuildScript for Plamo Linux 4.5
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2008-12-09
+#	BuildScript for Plamo Linux 4.7
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-09-18
 # require:
-HTTPD_VER=2.2.10
+HTTPD_VER=2.2.14
 HTTPD=httpd-$HTTPD_VER
-#	postgresql-8.3.x
+#	postgresql-8.4.x
 #	re2c-0.12.2
 #PHP
-VERSION=5.2.8
+VERSION=5.2.12
 #VERSION=5.2.7RC4
 #SUHOSIN
 # ex. http://download.suhosin.org/suhosin-0.9.27.tgz
-SUHOSIN=suhosin-0.9.27
-# ex. http://download.suhosin.org/suhosin-patch-5.2.7-0.9.6.3.patch.gz
+SUHOSIN=suhosin-0.9.29
+# ex. http://download.suhosin.org/suhosin-patch-5.2.x-0.9.x.patch.gz
 PAT_VER=
-#PAT_VER=0.9.6.3
+#PAT_VER=0.9.7
 DOC_ONLY=
 #DOC_ONLY=-1	# -1: php binary package only
 #DOC_ONLY=1	# 1: document package only
@@ -33,8 +33,6 @@ SRC_URI="http://jp.php.net/get/$SRC_FILE/from/this/mirror"
 if [ "$PAT_VER" != "" ]; then
   PAT_FILE=suhosin-patch-${VERSION}-${PAT_VER}.patch.gz
   PAT_URI="http://download.suhosin.org//$PAT_FILE"
-  #http://download.suhosin.org/
-  #suhosin-patch-5.2.7-0.9.6.3.patch.gz
 fi
 #MBPAT_FILE=mbstring-jpr-25298-20050414.patch.diff.gz
 #MBPAT_URI=http://www.voltex.jp/patches/$MBPAT_FILE
@@ -45,15 +43,16 @@ SYS_NAME="${CPU}-${REL}"
 
 PLAMO=/expo/Build
 SRC_DIR=$PLAMO/Archive/www/php
-PAC_DIR=$PLAMO/Packages/4.5/09_webdb/03_PHP.tgz/
-BUILD_DIR=$PLAMO/php52
+PAC_DIR=$PLAMO/Packages/4.7/09_webdb/03_PHP.tgz/
+BUILD_DIR=$PLAMO/php5
 CUSTOM_DIR=$BUILD_DIR/Custom
-CUSTOM_PAT=php-5.2.6-strict-session.patch
+# patch the following if suhosin patch is not applied.
+#CUSTOM_PAT=php-5.2.6-strict-session.patch
 # http://wiki.ohgaki.net/index.php?plugin=attach&refer=PHP%2Fpatch%2FStrictSession&openfile=php-5.2.6-strict-session.patch
 # which include http://www.suspekt.org/session_strict_mode.patch
 
 #PREFIX=usr
-PREFIX=opt/php5
+PREFIX=opt/$PAC_NAME
 #DESTDIR=opt/$PAC_NAME
 #CONFIG=etc
 CONFIG=$PREFIX/etc
@@ -72,7 +71,7 @@ if [ ! -f $SRC_DIR/$SRC_FILE ]; then
 fi
 if [ "x$PAT_VER" != "x" ]; then
   if [ ! -f $SRC_DIR/$PAT_FILE ]; then
-    (cd $SRC_DIR; wget $PAT_URI);
+    (cd $SRC_DIR; wget -N $PAT_URI);
   fi
 fi
 
@@ -110,55 +109,66 @@ if [ -d $PAC_NAME ]; then
  rm -rf ${PAC_NAME}/doc-pak/
 fi
 
-tar xvfz $SRC_DIR/$SRC_FILE
-# exit
-cd ${PAC_NAME}
-if [ "x$PAT_VER" != "x" ]; then
-  zcat $SRC_DIR/$PAT_FILE | patch -p1
-fi
-if [ -f $CUSTOM_DIR/$CUSTOM_PAT ]; then
-  cat $CUSTOM_DIR/$CUSTOM_PAT | patch -p1
+if [ ! -d $PAC_NAME ]; then
+ tar xvfz $SRC_DIR/$SRC_FILE
+ # exit
+ cd ${PAC_NAME}
+ if [ "x$PAT_VER" != "x" ]; then
+   zcat $SRC_DIR/$PAT_FILE | patch -p1
+ fi
+ if [ -f $CUSTOM_DIR/$CUSTOM_PAT ]; then
+   cat $CUSTOM_DIR/$CUSTOM_PAT | patch -p1
+ fi
+else
+ cd ${PAC_NAME}
 fi
+
 #	if `false`; then
 ./configure  --prefix=/$PREFIX --with-config-file-path=/$CONFIG \
   --with-apxs2=/opt/httpd/bin/apxs --with-pear \
   --enable-zend-multibyte --enable-mbstring --enable-mbregex \
-  --enable-exif --enable-soap --enable-sockets --enable-dbx --with-zlib \
+  --enable-exif --enable-soap --enable-sockets --with-zlib \
   --enable-sysvmsg --enable-sysvsem --enable-sysvshm --enable-shmop \
   --with-readline --enable-ftp --with-openssl \
   --with-pgsql  --with-pdo-pgsql=/opt/pgsql \
   --enable-sqlite-utf8
 
-  #--with-config-file-scan-dir
+#  #--with-config-file-scan-dir
+#	fi
 
 make
-mv /opt/httpd/conf/httpd.conf /opt/httpd/conf/httpd.conf.orig
-make install
-mv /opt/httpd/conf/httpd.conf.orig /opt/httpd/conf/httpd.conf
+cp -p /opt/httpd/conf/httpd.conf /opt/httpd/conf/httpd.conf.orig
+mv -v /opt/httpd/modules/libphp5.so /opt/httpd/modules/libphp5.so.orig
+
+make -i install
+mv -v /opt/httpd/conf/httpd.conf.orig /opt/httpd/conf/httpd.conf
 
 mkdir -p $WORK/opt/htdocs
 
 export PATH=/$PREFIX/bin:$PATH
 
-pear install --alldeps DB
-pear install --alldeps Auth
-pear install --alldeps Auth_SASL
-pear install --alldeps HTML_Template_IT
-#pear install HTML_Common HTML_QuickForm HTML_QuickForm_Controller
-pear install --alldeps HTML_QuickForm HTML_QuickForm_Controller
-#pear install XML_Parser XML_Util Config
-pear install --alldeps Config
-pear install --alldeps DB
-pear install --alldeps Mail_Mime
-#pear install Net_Socket HTTP_Request
-pear install --alldeps HTTP_Request
-pear install --alldeps -f Net_URL
-pear install --alldeps -f SOAP
-# pear install Date Calendar
-pear install --alldeps -f Calendar
+rm -rf /$PREFIX/lib/php/.channels/
+/$PREFIX/bin/pear upgrade
+
+/$PREFIX/bin/pear install --alldeps DB
+/$PREFIX/bin/pear install --alldeps Auth
+/$PREFIX/bin/pear install --alldeps Auth_SASL
+/$PREFIX/bin/pear install --alldeps HTML_Template_IT
+#/$PREFIX/bin/pear install HTML_Common HTML_QuickForm HTML_QuickForm_Controller
+/$PREFIX/bin/pear install --alldeps HTML_QuickForm HTML_QuickForm_Controller
+#/$PREFIX/bin/pear install XML_Parser XML_Util Config
+/$PREFIX/bin/pear install --alldeps Config
+/$PREFIX/bin/pear install --alldeps MDB2
+/$PREFIX/bin/pear install --alldeps Mail_Mime
+#/$PREFIX/bin/pear install Net_Socket HTTP_Request
+/$PREFIX/bin/pear install --alldeps HTTP_Request
+/$PREFIX/bin/pear install --alldeps -f Net_URL
+/$PREFIX/bin/pear install --alldeps -f SOAP
+# /$PREFIX/bin/pear install Date Calendar
+/$PREFIX/bin/pear install --alldeps -f Calendar
 
 
-pear upgrade-all
+/$PREFIX/bin/pear upgrade-all
 
 ZTS=`sh ./scripts/php-config --extension-dir`
 
@@ -492,14 +502,12 @@ __EOFuploadprogress
 $ZTS/bcompiler.so
 __EOFbcompiler
 
-
-  cd ..
 cd ..
-
+pwd
 
 mkdir -p $WORK/$DOC_DIR
 cp -p $BUILD_DIR/`basename $0`  \
-      CODING_STANDARDS CREDITS EXTENSIONS INSTALL LICENSE UPGRADING \
+      CODING_STANDARDS CREDITS EXTENSIONS INSTALL LICENSE NEWS UPGRADING  \
       README* TODO* \
 	$WORK/$DOC_DIR/
 chown -R root.root $WORK/$DOC_DIR
@@ -537,12 +545,13 @@ mkdir -p opt/$HTTPD/conf/conf.d
 cp $CUSTOM_DIR/httpd.php5-sample.conf opt/$HTTPD/conf/conf.d/
 mkdir -p opt/$HTTPD/modules
 cp -p /opt/$HTTPD/modules/libphp5.so opt/$HTTPD/modules/libphp5.so.$VERSION
+cp -p /opt/$HTTPD/modules/libphp5.so.orig /opt/$HTTPD/modules/libphp5.so
 mkdir -p opt/$HTTPD/man/man1
 cp -p /opt/$HTTPD/man/man1/*.1 opt/$HTTPD/man/man1/
 gzip opt/$HTTPD/man/man1/*.1
 
 cp -av $CUSTOM_DIR/htdocs/* $WORK/opt/htdocs/
-tar xvfz $CUSTOM_DIR/emacssl.tgz -C usr/share
+tar xvfz $CUSTOM_DIR/emacssl.tgz -C $WORK/usr/share
 curl -o $CUSTOM_DIR/php_browscap.ini http://browsers.garykeith.com/stream.asp\?PHP_BrowsCapINI
 cp $CUSTOM_DIR/php_browscap.ini $WORK/$PREFIX/lib/php/
 
@@ -580,7 +589,7 @@ __EOCL__
 
 
 # Make Package
-tar cvfz ${PACKAGE}.tgz $PREFIX/*/* opt/${HTTPD}/*/* $DOC_DIR usr/share/emacs/site-lisp/*  opt/htdocs/* $CONFIG/php.ini-plamo etc/profile.d/php5.* install/doinst.sh 
+tar cvfz ${PACKAGE}.tgz $PREFIX/*/* opt/${HTTPD}/*/* $DOC_DIR usr/share/emacs/site-lisp/*  opt/htdocs/* $CONFIG/php.ini-plamo etc/profile.d/php5.* install/doinst.sh > package.lis
 mv -v ${PACKAGE}.tgz $PAC_DIR
 echo "$PAC_DIR/${PACKAGE}.tgz ... done"
 cd $CWD
@@ -598,7 +607,7 @@ fi
 ##
 ## Make Document Package
 ##
-DOCPAC=php_doc_ja-${VERSION}-noname-${REL}
+DOCPAC=php_doc_ja-${VERSION}-noarch-${REL}
 LOGF=/tmp/wgetlog$$
 (cd $SRC_DIR; \
  wget -N $DOC_URI > $LOGF 2>&1)
